@@ -6,7 +6,7 @@ module DataMapper
     #
     # @return <YAML> a YAML representation of this Resource
     def to_yaml(opts_or_emitter = {})
-      if opts_or_emitter.is_a?(YAML::Syck::Emitter)
+      if !opts_or_emitter.is_a?(Hash)
         emitter = opts_or_emitter
         opts = {}
       else
@@ -16,8 +16,7 @@ module DataMapper
 
       YAML::quick_emit(object_id,emitter) do |out|
         out.map(nil,to_yaml_style) do |map|
-          propset = properties_to_serialize(opts)
-          propset.each do |property|
+          properties_to_serialize(opts).each do |property|
             value = send(property.name.to_sym)
             map.add(property.name, value.is_a?(Class) ? value.to_s : value)
           end
@@ -37,7 +36,7 @@ module DataMapper
 
   class Collection
     def to_yaml(opts_or_emitter = {})
-      if opts_or_emitter.is_a?(YAML::Syck::Emitter)
+      if !opts_or_emitter.is_a?(Hash)
         to_a.to_yaml(opts_or_emitter)
       else
         # FIXME: Don't double handle the YAML (remove the YAML.load)
@@ -45,4 +44,16 @@ module DataMapper
       end
     end
   end
+
+  if Serialize::Support.dm_validations_loaded?
+
+    module Validate
+      class ValidationErrors
+        def to_yaml(*args)
+          errors.to_hash.to_yaml(*args)
+        end
+      end
+    end
+
+  end
 end
