@@ -6,6 +6,6 @@ class Cow
   property :name,      String
   property :breed,     String
 
-  has n, :baby_cows, :class_name => 'Cow'
-  belongs_to :mother_cow, :class_name => 'Cow'
+  belongs_to :mother_cow, :model => self, :nullable => true
+  has n, :baby_cows, :model => self, :child_key => [ :mother_cow_id, :mother_cow_composite ]
 end
