@@ -1,5 +1,4 @@
-require 'pathname'
-require Pathname(__FILE__).dirname.expand_path.parent + 'spec_helper'
+require 'spec_helper'
 
 describe DataMapper::Serialize, '#to_json' do
   #
@@ -10,10 +9,14 @@ describe DataMapper::Serialize, '#to_json' do
     DataMapper.auto_migrate!
     query = DataMapper::Query.new(DataMapper::repository(:default), Cow)
 
-    @collection = DataMapper::Collection.new(query) do |c|
-      c.load([1, 2, 'Betsy', 'Jersey'])
-      c.load([10, 20, 'Berta', 'Guernsey'])
-    end
+    keys = %w[ id composite name breed ]
+
+    resources = [
+      keys.zip([  1,  2, 'Betsy', 'Jersey'   ]).to_hash,
+      keys.zip([ 10, 20, 'Berta', 'Guernsey' ]).to_hash,
+    ]
+
+    @collection = DataMapper::Collection.new(query, query.model.load(resources, query))
 
     @harness = Class.new(SerializerTestHarness) do
       def method_name
